Functions available only to privileged apps.
Structs
Functions
- append_
file - create_
dir - dump_
file - get_
file_ size - load_
file - Read a file from the filesystem into the buffer.
- load_
file_ buf - Like
load_filebut takes care of the buffer allocation and ownership. - remove_
dir - remove_
file - run_app
- Tell runtime to exit the current app and replace it with the given one.