load_file

Function load_file 

pub fn load_file<'a>(path: &str, buf: &'a mut [u8]) -> FileRef<'a>
Read a file from the filesystem into the buffer.

The path must be relative to the root of the FS. For example: sys/launcher.