load_file_buf

Function load_file_buf 

pub fn load_file_buf(path: &str) -> Option<FileBuf>
Like load_file but takes care of the buffer allocation and ownership.

None is returned if the file does not exist.