run_app

Function run_app 

pub fn run_app(author_id: &str, app_id: &str)
Tell runtime to exit the current app and replace it with the given one.

The exit will be executed after the current frame is rendered. Calling this function does not interrup the current app execution.