Module sudo

Module sudo 

Functions available only to privileged apps.

Structs

Dir
DirBuf
DirIter

Functions

append_file
create_dir
dump_file
get_file_size
load_file
Read a file from the filesystem into the buffer.
load_file_buf
Like load_file but takes care of the buffer allocation and ownership.
remove_dir
remove_file
run_app
Tell runtime to exit the current app and replace it with the given one.